@@ -12,6 +12,7 @@ DT_PREFIX = "dt"
 OPENGIS_NAMESPACE = "http://www.opengis.net/ont/geosparql#"
 OPENGIS_PREFIX = "geo"
 
+LANG_STRING_TYPE = "http://www.w3.org/1999/02/22-rdf-syntax-ns#langString"
 STRING_TYPE = "http://www.w3.org/2001/XMLSchema#string"
 FLOAT_TYPE = "http://www.w3.org/2001/XMLSchema#float"
 INTEGER_TYPE = "http://www.w3.org/2001/XMLSchema#int"
@@ -33,6 +34,7 @@ def remove_corners(a_uri, raise_error_if_no_corners=True):
 def add_corners(a_uri):
     return "<" + a_uri + ">"
 
+
 def add_corners_if_it_is_an_uri(a_candidate_uri):
     if a_candidate_uri.startswith("http://"):
         return "<" + a_candidate_uri + ">"
@@ -40,9 +42,9 @@ def add_corners_if_it_is_an_uri(a_candidate_uri):
 
 
 def decide_literal_type(a_literal):
-    if "\"^^" not in a_literal:
-        return STRING_TYPE
-    elif there_is_arroba_after_last_quotes(a_literal):
+    if there_is_arroba_after_last_quotes(a_literal):
+        return LANG_STRING_TYPE
+    elif "\"^^" not in a_literal:
         return STRING_TYPE
     elif "xsd:" in a_literal:
         return XSD_NAMESPACE + a_literal[a_literal.find("xsd:") + 4:]
